cd "SET DIRECTORY\tables"
set more 1
set matsize 5000

//FIGURE A6: Observational data on spending type over time
import excel "..\us_foreignaid_greenbook.xlsx", sheet("Economic and Military Aid") firstrow case(lower) clear
destring fiscal, force replace
collapse (sum) obligationsconstantdollars, by(fiscalyear assistancecategory)
replace obligationsconstantdollars=obligationsconstantdollars/1000000
twoway (line obligationsconstantdollars fiscalyear if assistancecategory=="Economic", lcolor(black)) (line obligationsconstantdollars fiscalyear if assistancecategory=="Military", lcolor(gs10)), graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  legend(order(1 2) label(1 "Economic") label(2 "Military") region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small))  xlabel(1946(10)2016) ytitle("U.S. Foreign Aid in Constant Dollars ($1m)")
graph export "A6_aid_type_obs.eps", as(eps) replace

//distributions.do contains code used to generate distributions of country characteristics used in experiment. Distributions and comparisons to distributions of observed characteristics of "named" countries used in design are reported in Appendix Figure A1
include ..\distributions.do

/* RENAMING AND "CLEANING" OF VARIABLES FROM FULL, PRIVATE DATASET; RETAIN ONLY VARIABLES USED IN ANALYSIS
use "..\private_full_data.dta", clear
**Drop cases where technical error led to errant country characteristics in Named Condition
drop if responseid==1841 | responseid==2015 | responseid==2972 |responseid==3036
**conjoint outcomes (choices)
rename iprefer  conjoint_1
rename v229 conjoint_2
rename v232 conjoint_3
rename v235 conjoint_4
rename v238 conjoint_5
rename v241 conjoint_6
rename v244 conjoint_7
rename v247 conjoint_8
rename v250 conjoint_9
rename v254 conjoint_10
*** stated criteria
rename thecountryreceivingtheaidhasalar fa_population
rename thecountrypurchasesalotofusexpor fa_exports
rename aidwillgotowardsmilitaryprojects fa_military
rename aidwillgotowardhumanitarianproje fa_humanitarian
rename thecountryreceivingtheaidisademo fa_freedom
rename thepeopleinthecountryreceivingth fa_income
rename theaidpackagecostsmorethan40mill fa_cost

keep conjoint_* fa_* att* time_conjoint_* educ income incomemis age r_* female region_* responseid IncreasingspendingonforeignaidPl thinkingaboutyourlifethesedaysap wehearalotoftalkthesedaysaboutli polinterest wouldyoucallyourselfastrongdemoc wouldyoucallyourselfastrongrepub doyouthinkofyourselfasclosertoth ifyouhadtochoosewhichpartywouldy generallyspeakingdoyouusuallythi 
save "..\conjoint_data.dta"
*/

use "..\conjoint_data.dta", clear

rename thinkingaboutyourlifethesedaysap relig_att
label var relig_att "Freq. of Religious Attendance (1-5)"
gen ideology = wehearalotoftalkthesedaysaboutli-4
label var ideology "Ideology (-3 = v. lib; 3 = v. cons.)"
recode polinterest (1=3) (2=2) (3=1)
*party ID
egen partyid=rmean(wouldyoucallyourselfastrongdemoc wouldyoucallyourselfastrongrepub doyouthinkofyourselfasclosertoth ifyouhadtochoosewhichpartywouldy)
recode generallyspeakingdoyouusuallythi (1=1) (2=2) (3/4=3), gen(pid3) 
replace partyid = 0 if partyid<1 & partyid>-1
label var partyid "Party Identification (-3 = Str. Dem.; 3 = Str. Rep)"




***set sample
reg partyid educ income incomemis age r_* female region_* , r
keep if e(sample)
egen tasks_miss=rownonmiss(conjoint_1 conjoint_2 conjoint_3 conjoint_4 conjoint_5 conjoint_6 conjoint_7 conjoint_8 conjoint_9 conjoint_10)
drop if tasks_miss!=10
outsum partyid educ income incomemis age r_* female region_* using "A2_sumstats", replace bracket
drop r_white region_ne

*******CONJOINTS
**order of characteristics was randomized, so, e.g., att1_t1_a was the income descriptor for some, purpose for others, etc.
**Start by generating empty variables for the six/seven concepts presented in each case
*loop through characteristic names
foreach i in income cost country freedom population purpose exports{
*within loop, loop through tasks and generate a "Proposal A" and "Proposal B" placeholder 
foreach t in "01" "02" "03" "04" "05" "06" "07" "08" "09" "10" {
gen `i'_A_`t'=""
gen `i'_B_`t'=""
}
}
**replace missing values on those just-generated empty variables with values based on which attribute was attribute 1, 2, 3, etc for each respondent
foreach i in "01" "02" "03" "04" "05" "06" "07" "08" "09" "10" {
forvalues a=1/7 {
//e.g., set income_A_01 to the value of att01_t1_a if atribute 1 (i.e., `a') = "Avg. Income.."
replace income_A_`i'=att`a'_t`i'_a if conjoint_att_`a'=="Average Annual Income in Country"
replace income_B_`i'=att`a'_t`i'_b if conjoint_att_`a'=="Average Annual Income in Country"
replace cost_A_`i'=att`a'_t`i'_a if conjoint_att_`a'=="Cost of Aid Package"
replace cost_B_`i'=att`a'_t`i'_b if conjoint_att_`a'=="Cost of Aid Package"
replace country_A_`i'=att`a'_t`i'_a if conjoint_att_`a'=="Country Receiving Aid"
replace country_B_`i'=att`a'_t`i'_b if conjoint_att_`a'=="Country Receiving Aid"
replace freedom_A_`i'=att`a'_t`i'_a if conjoint_att_`a'=="Level of Political Freedom in Country (100 = Most Free)"
replace freedom_B_`i'=att`a'_t`i'_b if conjoint_att_`a'=="Level of Political Freedom in Country (100 = Most Free)"
replace population_A_`i'=att`a'_t`i'_a if conjoint_att_`a'=="Population of Country"
replace population_B_`i'=att`a'_t`i'_b if conjoint_att_`a'=="Population of Country"
replace purpose_A_`i'=att`a'_t`i'_a if conjoint_att_`a'=="Proposal Would Fund"
replace purpose_B_`i'=att`a'_t`i'_b if conjoint_att_`a'=="Proposal Would Fund"
replace exports_A_`i'=att`a'_t`i'_a if conjoint_att_`a'=="Total U.S. Exports to Country (2017)"
replace exports_B_`i'=att`a'_t`i'_b if conjoint_att_`a'=="Total U.S. Exports to Country (2017)"
}
}

**replace the 01, 02, etc with 1, 2; replace A and B with 1 and 2 (need to do this before reshaping the data
foreach i of varlist income_* cost_* country_* freedom_* population_* purpose_* exports_* time_conjoint_* {
local name1 = subinstr("`i'","_0","_",.)
local name2 = subinstr("`name1'","A","1",.)
local name = subinstr("`name2'","B","2",.)
rename `i' `name'
}

*** stated criteria (center at midpoint)
foreach i of varlist fa_*{
replace `i'=`i'-4
}
label var fa_population "The country receiving the aid has a large population (-3 to 3)"
label var fa_exports "The country purchases a lot of U.S. exports (-3 to 3)"
label var fa_military "Aid will go towards military projects in that country (-3 to 3)"
label var fa_humanitarian "Aid will go toward humanitarian projects in that country (-3 to 3)"
label var fa_freedom "The country receiving the aid is a democracy (-3 to 3)"
label var fa_income "The people in the country receiving the aid are poor (-3 to 3)"
label var fa_cost "The aid package costs more than $40 million (-3 to 3)"

**support for foreign aid spending
*rename income vars so not to confuse w/ctry income
rename income famincome
rename incomemis famincome_mis


*reshape to stack tasks (here reshaping wide [a bunch of tasks listed "horizontally"] to long stack choice tasks on top of one another)
reshape long income_1_ income_2_ cost_1_ cost_2_ country_1_ country_2_ freedom_1_ freedom_2_ population_1_ population_2_ purpose_1_ purpose_2_ exports_1_ exports_2_ conjoint_ time_conjoint_, i(responseid) j(task)
//create choose A/B vars (indicators for "chose proposal 1" and "chose proposal 2"
rename conjoint_ conjoint_2
recode conjoint_2 (1=0) (0=1), gen(conjoint_1)
//drop underscore at end of var names (again, needed to reshape data)
foreach i in income_1_ income_2_ cost_1_ cost_2_ country_1_ country_2_ freedom_1_ freedom_2_ population_1_ population_2_ purpose_1_ purpose_2_ exports_1_ exports_2_ {
local name1 = subinstr("`i'","2_","2",.)
local name = subinstr("`name1'","1_","1",.)
rename `i' `name'
}


keep income_1 income_2 cost_1 cost_2 country_1 country_2 freedom_1 freedom_2 population_1 population_2 purpose_1 purpose_2 exports_1 exports_2 conjoint_1 conjoint_2 fa_* task partyid time_conjoint_ polinterest relig_att ideology educ famincome famincome_mis age r_* female responseid

***for frequency of cases where less expensive chosen / humanitarian chosen over military
forvalue i = 1/2{
gen temp_cost_`i'=cost_`i'
replace temp_cost_`i'=subinstr(temp_cost_`i'," million","",.)
replace temp_cost_`i'=subinstr(temp_cost_`i',"$","",.)
destring temp_cost_`i', replace
label var temp_cost_`i' "Opt `i': Cost (in $millions)"
gen temp_mil_purpose_`i' = 0
replace temp_mil_purpose_`i'=1 if purpose_`i'=="Military equipment"
replace temp_mil_purpose_`i'=1 if purpose_`i'=="Military facilities"
replace temp_mil_purpose_`i'=1 if purpose_`i'=="Military training"
label var temp_mil_purpose_`i' "Opt `i': Military Aid (1=yes)"
gen temp_freedom_`i'=freedom_`i'
replace temp_freedom_`i'=subinstr(temp_freedom_`i'," (out of 100)","",.)
destring temp_freedom_`i', replace
label var temp_freedom_`i' "Opt `i': Freedom Score (0-100)"
}

gen opt_1_cheaper=temp_cost_1<temp_cost_2
replace opt_1_cheaper=. if temp_cost_1==temp_cost_2
gen chose_cheaper=(conjoint_1==0 & opt_1_cheaper==0) | (conjoint_1==1 & opt_1_cheaper==1) 
replace chose_cheaper=. if opt_1_cheaper==.
//cheaper option selected 56% of the time (28.41+ 27.56), more expensive 44% 
tab chose_cheaper

gen opt_1_freer=temp_freedom_1>temp_freedom_2
replace opt_1_freer=. if temp_freedom_1==temp_freedom_2
gen chose_freer=(conjoint_1==0 & opt_1_freer==0) | (conjoint_1==1 & opt_1_freer==1) 
replace chose_freer=. if opt_1_freer==.
//freer option selected 56% of the time, less free 44% 
tab chose_freer

gen only_opt_1_humanitarian=(temp_mil_purpose_1==0) & (temp_mil_purpose_2==1) 
replace only_opt_1_humanitarian=. if temp_mil_purpose_1==temp_mil_purpose_2
gen chose_human=(conjoint_1==0 & only_opt_1_humanitarian==0) | (conjoint_1==1 & only_opt_1_humanitarian==1) 
replace chose_human=. if only_opt_1_humanitarian==.
//humanitarian option selected 68.3% of the time (33.81+34.53)
tab chose_human

preserve
collapse (mean) chose_human chose_freer chose_cheaper educ famincome famincome_mis female r_black r_hispanic r_asian r_other relig_att ideol partyid fa_*, by(responseid)
foreach i in chose_human chose_cheaper chose_freer{
qui sum `i', det
local median=r(p50)
local mean=r(mean)

//fix Stata's precision pecuiliarities (refusal to round sensibly) with binning of histograms
forvalues r=0(.1).9{
replace `i'=`r'+.00001 if `i'>(`r'-.01) &`i'<(`r'+.01)  
}
if "`i'"=="chose_cheaper"{
local xaxis = "Panel A: ...cheaper package."
}
if "`i'"=="chose_freer"{
local xaxis = "Panel B: ...package targeting freer country."
}
if "`i'"=="chose_human"{
local xaxis = "Panel C: ...economic over military."
}
histogram `i', percent bin(10) xtitle("") title("`xaxis'",  size(medsmall) height(7))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(off) ytitle("") legend(off) xline(`median', lcolor(black) lpattern(dash)) xline(`mean', lcolor(black))  fcolor(gs10) lcolor(gs8)
graph save Graph "hist_`i'.gph", replace
}
graph combine  hist_chose_cheaper.gph hist_chose_freer.gph hist_chose_human.gph,  l1title("% of Respondents", size(medsmall)) title("Proportion of tasks where respondent chose...", size(medium)) cols(1) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) ycommon ysize(20) xsize(15)
graph export "A2_choice_uniformity.eps", as(eps)  replace
restore

*reshape to stack *proposals* (e.g., stack proposal B "under" proposal A)
gen conjoint_task=_n
reshape long income_ cost_ country_ freedom_ population_ purpose_ exports_ conjoint_, i(conjoint_task) j(proposal)

**destring--remove non-numeric characters from each variable (e.g., "$11 million" --> 11)
replace cost_=subinstr(cost_," million","",.)
replace cost_=subinstr(cost_,"$","",.)
destring cost_, replace
label var cost_ "Cost (in $millions)"
replace freedom_=subinstr(freedom_," (out of 100)","",.)
destring freedom_, replace
label var freedom_ "Freedom Score (0-100)"
gen mil_purpose = 0
replace mil_purpose=1 if purpose_=="Military equipment"
replace mil_purpose=1 if purpose_=="Military facilities"
replace mil_purpose=1 if purpose_=="Military training"
label var mil_purpose "Military"
replace income_=subinstr(income_,"$","",.)
replace income_=subinstr(income_,",","",.)
destring income_, replace
replace income = income/1000
label var income "Avg. Annual Income (in 1,000s)"
replace population_=subinstr(population_," million","",.)
destring population_, replace
replace population_=population_/10
label var population_ "Population (10s of millions)"


**exports (deal with billion v. million)
gen exp_bil=0
replace exp_bil=1 if subinstr(exports_,"billion","",.)!=exports_

replace exports_=subinstr(exports_,"$","",.)
replace exports_=subinstr(exports_," million","",.)
replace exports_=subinstr(exports_," billion","",.)
destring exports_, replace
replace exports_ = exports_ * 1000 if exp_bil==1
replace exports_ =exports_ /1000
label var exports_ "U.S. Exports (2017; in billions)"

**generate country indicator variables
tab country, mis gen(ctry_)
foreach i of varlist ctry_* {
local label : variable label `i'
local label2 = subinstr("`label'","country_==","",.)
label var `i' "`label2'"
}
label var ctry_4 "DR Congo"
** generate purpose indicators
tab purpose, gen(purp_)
foreach i of varlist purp_* {
local label : variable label `i'
local label2 = subinstr("`label'","purpose_==","",.)
label var `i' "`label2'"
}
label var purp_2 "Disaster prevention/preparedness"

//RESCALE So 0-1 = low to high
foreach v in cost freedom income population exports{
qui sum `v'
gen full_`v'=(`v'-r(min))/(r(max)-r(min))
gen zero_`v'=0
}
label var full_cost "Cost of Aid Package"
label var full_freedom  "Level of Political Freedom in Country"
label var full_income "Average Annual Income in Country"
label var full_population "Population of Country"
label var full_exports "Exports to Country"

recode cost_ (0/25=1) (25/50=2) (50/75=3) (75/100=4), gen(cost_bins)
tab cost_bins, gen(bins_cost_)
drop bins_cost_1
label var zero_cost "$1-25 million"
label var bins_cost_2 "$26-50 million"
label var bins_cost_3 "$51-75 million"
label var bins_cost_4 "$76-100 million"

recode freedom (0/35=1) (35/70=2) (70/100=3), gen(freedom_bins)
tab freedom_bins, gen(bins_freedom_)
drop bins_freedom_1
label var zero_freedom "0-35"
label var bins_freedom_2 "36-70"
label var bins_freedom_3 "71-100"

recode income (0/2=1) (2/10=2) (10/100=3), gen(income_bins)
tab income_bins, gen(bins_income_)
drop bins_income_1
label var zero_income "$0-2,000/year"
label var bins_income_2 "$2,000-10,000/year"
label var bins_income_3 "$10,000+/year "

recode population (0/2.5=1) (2.5/8=2) (8/100=3), gen(population_bins)
tab population_bins, gen(bins_population_)
drop bins_population_1
label var zero_population "0-25 million"
label var bins_population_2 "25 to 80 million"
label var bins_population_3 "80+ million"

recode exports (0/1=1) (1/2=2) (2/100=3), gen(exports_bins)
tab exports_bins, gen(bins_exports_)
drop bins_exports_1
label var zero_exports "$0-1 billion"
label var bins_exports_2 "$1-2 billion"
label var bins_exports_3 "$2+ billion"
gen zero_purpose=0
label var zero_purpose "Economic"

//RESCALE SO 0-1 = 25th-75th percentile (1-100m for cost)
gen pctile_freedom=(freedom_-27)/(60.5-27)
gen pctile_income=(income_-1.795)/(9.995-1.795)
gen pctile_population=(population_-1.2)/(6.85-1.2)
gen pctile_exports=(exports_-.28475)/(2.21195-.28475)
label var pctile_freedom "Level of Political Freedom in Country"
label var pctile_income "Average Annual Income in Country"
label var pctile_population "Population of Country"
label var pctile_exports "Exports to Country"

foreach i in M H{
gen label_`i'="`i'"
} 
//untransformed--for marginal effects not tied to full range of treatments (reported in body of paper)
reg conjoint_ cost_ freedom_ income_ population_ exports_ mil_purpose  if ctry_1==1, cluster( responseid)

//CORE AMCE ESTIMATES
reg conjoint_ zero_purpose mil_purpose zero_cost bins_cost_2 bins_cost_3 bins_cost_4 zero_freedom bins_freedom_2 bins_freedom_3 zero_income bins_income_2 bins_income_3 zero_population bins_population_2 bins_population_3 zero_exports bins_exports_2 bins_exports_3 if ctry_1==1, cluster( responseid)
eststo direct_FX
coefplot (direct_FX, msymbol(Oh) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Pooled)) , omitted xline(0, lcolor(black)) level(95) xtitle("{bf:Estimated Effect on Probability of Selecting Proposal}",  size(vsmall))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(-.2(.1).1, labsize(vsmall)) xscale(lw(none))  legend(off) coeflabels(,wrap(40)) drop(_cons) ysize(6) ylabel(,labsize(vsmall)) headings(zero_purpose = "{bf:Purpose of Aid}" zero_cost = "{bf:Cost of Aid Package}" zero_freedom = "{bf:Level of Political Freedom}" zero_income = "{bf:Average Annual Income}" zero_population = "{bf:Population}" zero_exports = "{bf:U.S. Exports to Country}", labsize(vsmall))
graph export "F2_direct_fx.eps", as(eps) replace

preserve
label var mil_purpose "Purpose: Military"
label var bins_cost_2 "Cost: $26-50 million"
label var bins_cost_3 "Cost: $51-75 million"
label var bins_cost_4 "Cost: $76-100 million"
label var bins_freedom_2 "Political Freedom Score: 36-70"
label var bins_freedom_3 "Political Freedom Score: 71-100"
label var bins_income_2 "Average Annual Income: $2,000-10,000/year"
label var bins_income_3 "Average Annual Income: $10,000+/year "
label var bins_population_2 "Population: 25 to 80 million"
label var bins_population_3 "Population: 80+ million"
label var bins_exports_2 "U.S. Exports: $1-2 billion"
label var bins_exports_3 "U.S. Exports: $2+ billion"
reg conjoint_ mil_purpose bins_cost_2 bins_cost_3 bins_cost_4 bins_freedom_2 bins_freedom_3 bins_income_2 bins_income_3 bins_population_2 bins_population_3 bins_exports_2 bins_exports_3 if ctry_1==1, cluster( responseid)
outreg using "A3_core_model", se bracket tdec(3) replace label 
restore

*******COUNTRY CHAR FX CONDITIONAL ON AID TYPE?
foreach i in full_cost full_freedom  full_income full_population full_exports {
gen XmilX`i'=`i'*mil_purp
local label : variable label `i'
label var XmilX`i' "`label' x Military"
}

//CORE *LINEAR* ESTIMATES
reg conjoint_ mil_purpose full_cost full_freedom  full_income full_population full_exports  if ctry_1==1, cluster( responseid)
outreg using "A4_stated", se bracket tdec(3) replace label 
outreg using "A7_countries", se bracket tdec(3) replace label 


reg conjoint_ full_cost full_freedom  full_income full_population full_exports if ctry_1==1 & mil_purpose==1, cluster( responseid)
outreg using "A5_typemod", se bracket tdec(3) replace label ctitle(Military)
reg conjoint_ full_cost full_freedom  full_income full_population full_exports if ctry_1==1 & mil_purpose==0, cluster( responseid)
outreg using "A5_typemod", se bracket tdec(3) append label ctitle(Economic)
reg conjoint_ full_cost full_freedom  full_income full_population full_exports mil_purpose XmilX* if ctry_1==1, cluster( responseid)
outreg using "A5_typemod", se bracket tdec(3) append label ctitle(Aid Type Interactions)

drop XmilX*

**FIGURE TO SHOW FX CONDITIONAL ON TYPE OF AID (move from 25th-75th pctile)
reg conjoint_ mil_purpose full_cost pctile_freedom  pctile_income pctile_population pctile_exports if ctry_1==1, cluster( responseid)
margins, dydx(mil_purpose full_cost pctile_freedom  pctile_income pctile_population pctile_exports ) post
eststo direct_FX
reg conjoint_ full_cost pctile_freedom  pctile_income pctile_population pctile_exports if ctry_1==1 & mil_purpose==0, cluster( responseid)
margins, dydx(full_cost pctile_freedom  pctile_income pctile_population pctile_exports ) post
eststo direct_FX_hum
reg conjoint_ full_cost pctile_freedom  pctile_income pctile_population pctile_exports if ctry_1==1 & mil_purpose==1, cluster( responseid)
margins, dydx(full_cost pctile_freedom  pctile_income pctile_population pctile_exports ) post
eststo direct_FX_mil
coefplot (direct_FX, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Pooled)) (direct_FX_hum, msymbol(none) mlabel(label_H) mlabposition(0) mlabcolor(black) connect(none) mcolor(gs10) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Economic)) (direct_FX_mil, msymbol(none) mlabel(label_M) mlabposition(0) mlabcolor(black) connect(none) mcolor(gs10) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Military)), xline(0, lcolor(black)) level(95) xtitle("Estimated Effect on Probability of Selecting Proposal",  size(medsmall) height(7))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(off) coeflabels(,wrap(20)) 
graph export "A3_cond_direct_fx.eps", as(eps) replace

foreach i in cost freedom  income population exports {
gen X`i'Xstated=full_`i'*fa_`i'
local label : variable label full_`i'
label var X`i'Xstated "`label' x Stated Pref."
}
gen Xmil_purpose1Xstated=mil_purpose*fa_military 
gen Xmil_purpose2Xstated=mil_purpose*fa_humanitarian
label var Xmil_purpose1Xstated "Military Aid x Stated Preference for Military Aid"
label var Xmil_purpose2Xstated "Military Aid x Stated Preference for Economic Aid"
reg conjoint_ full_cost full_freedom  full_income full_population full_exports mil_purpose fa_* X* if ctry_1==1, cluster( responseid)
outreg using "A4_stated", se bracket tdec(3) append label 
drop X*

reg conjoint_ full_cost full_freedom  full_income full_population full_exports purp_9 purp_10 purp_11 purp_1 purp_2 purp_4 purp_5 purp_3 purp_6 purp_7 purp_12 if ctry_1==1, cluster( responseid)
outreg using "A6_purpose", se bracket tdec(3) replace label 
margins, dydx(purp_9 purp_10 purp_11 purp_1 purp_2 purp_4 purp_5 purp_3 purp_6 purp_7 purp_12) post
eststo direct_FX
coefplot (direct_FX, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny))) , xline(0, lcolor(black)) level(95) xtitle("Estimated Effect on Prob. of Selecting Proposal",  size(medsmall) height(7))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(off) note(NOTE: Reference category = Military equipment)
graph export "F3_purpose_fx.eps", as(eps)  replace
//graph export "f2_purpose_fx.tif", as(tif) width(4000) replace

reg conjoint_ full_cost full_freedom  full_income full_population full_exports mil_purpose ctry_10 ctry_2 ctry_14 ctry_17 ctry_3 ctry_5 ctry_11 ctry_7 ctry_12 ctry_21 ctry_19 ctry_18 ctry_16 ctry_15 ctry_6 ctry_20 ctry_4 ctry_8 ctry_13 ctry_9, cluster( responseid)
outreg using "A7_countries", se bracket tdec(3) append label 
margins, dydx(ctry_10 ctry_2 ctry_14 ctry_17 ctry_3 ctry_5 ctry_11 ctry_7 ctry_12 ctry_21 ctry_19 ctry_18 ctry_16 ctry_15 ctry_6 ctry_20 ctry_4 ctry_8 ctry_13 ctry_9) post
eststo country_FX
coefplot (country_FX, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny))) , xline(0, lcolor(black)) level(95) xtitle("Estimated Effect on Probability of Selecting Proposal",  size(medsmall) height(7))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(off) note(NOTE: Reference category = Country not named)
graph export "F4_country_fx.eps", as(eps) replace
//graph export "f3_country_fx.tif", as(tif) width(4000) replace

reg conjoint_ c.full_cost##c.full_freedom##c.full_income##c.full_population##c.full_exports##mil_purpose ctry_10	ctry_2	ctry_14	ctry_3	ctry_17	ctry_7	ctry_21	ctry_19	ctry_18	ctry_6	ctry_16	ctry_11	ctry_5	ctry_8	ctry_20	ctry_12	ctry_4	ctry_15	ctry_13	ctry_9, cluster( responseid)
outreg ctry_10	ctry_2	ctry_14	ctry_3	ctry_17	ctry_7	ctry_21	ctry_19	ctry_18	ctry_6	ctry_16	ctry_11	ctry_5	ctry_8	ctry_20	ctry_12	ctry_4	ctry_15	ctry_13	ctry_9 using "A7_countries", se bracket tdec(3) append label ctitle("Full Interactions")

*** interact country w/military
recode mil_purp (1=0) (0=1), gen(hum_purp)
label var hum_purp "Economic Aid"
foreach i of varlist ctry_2-ctry_21{
gen XmilX`i'=`i'*mil_purp
gen XhumX`i'=`i'*hum_purp
local label : variable label `i'
label var XmilX`i' "`label' x Military"
label var XhumX`i' "`label' x Economic"
}

reg conjoint_ full_cost full_freedom  full_income full_population full_exports ctry_10	ctry_2	ctry_14	ctry_3	ctry_17	ctry_7	ctry_21	ctry_19	ctry_18	ctry_6	ctry_16	ctry_11	ctry_5	ctry_8	ctry_20	ctry_12	ctry_4	ctry_15	ctry_13	ctry_9 if mil_purpose==1, cluster( responseid)
outreg using "A7_countries", se bracket tdec(3) append label ctitle(Military)
margins, dydx(ctry_10	ctry_2	ctry_14	ctry_3	ctry_17	ctry_7	ctry_21	ctry_19	ctry_18	ctry_6	ctry_16	ctry_11	ctry_5	ctry_8	ctry_20	ctry_12	ctry_4	ctry_15	ctry_13	ctry_9) post
eststo country_FX_mil
coefplot (country_FX_mil, msymbol(Oh) connect(none) mcolor(gs6) msize(small) ciopts(lcolor(gs6) lwidth(thin) msize(vtiny)) label(Military Aid)) , xline(0, lcolor(black)) level(95)  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  title("Panel A: Military Aid", size(medsmall)) legend(off) ylabel(, labsize(vsmall)) 
graph save Graph "fX_country_cond_a.gph", replace

reg conjoint_ full_cost full_freedom  full_income full_population full_exports ctry_10	ctry_17	ctry_2	ctry_11	ctry_5	ctry_14	ctry_12	ctry_3	ctry_7	ctry_15	ctry_21	ctry_16	ctry_18	ctry_19	ctry_4	ctry_20	ctry_6	ctry_13	ctry_9	ctry_8 if mil_purpose==0, cluster( responseid)
outreg using "A7_countries", se bracket tdec(3) append label ctitle(Economic)
margins, dydx(ctry_10	ctry_17	ctry_2	ctry_11	ctry_5	ctry_14	ctry_12	ctry_3	ctry_7	ctry_15	ctry_21	ctry_16	ctry_18	ctry_19	ctry_4	ctry_20	ctry_6	ctry_13	ctry_9	ctry_8) post
eststo country_FX_hum
coefplot (country_FX_hum, msymbol(Oh) connect(none) mcolor(gs6) msize(small) ciopts(lcolor(gs6) lwidth(thin) msize(vtiny)) label(Economic Aid)) , xline(0, lcolor(black)) level(95)  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  title("Panel B: Economic Aid", size(medsmall)) legend(off) ylabel(, labsize(vsmall)) 
graph save Graph "fX_country_cond_b.gph", replace

reg conjoint_ full_cost full_freedom  full_income full_population full_exports mil_purpose ctry_10	ctry_11	ctry_17	ctry_2	ctry_5	ctry_14	ctry_12	ctry_3	ctry_7	ctry_15	ctry_21	ctry_16	ctry_18	ctry_19	ctry_4	ctry_20	ctry_6	ctry_13	ctry_8	ctry_9 XmilX*, cluster( responseid)
outreg using "A7_countries", se bracket tdec(3) append label 

graph combine fX_country_cond_a.gph fX_country_cond_b.gph,  cols(2) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) ycommon b1title("Estimated Effect on Probability of Selecting Proposal",  size(medsmall))note(NOTE: Reference category = Country not named) 
graph export "A5_country_cond.eps", as(eps) replace


//PARTY interactions
recode partyid (-3/-1=1) (0=2) (1/3=3), gen(pid3)
label var pid3 "Party ID (1 = D; 2 = PI; 3 = R)"
tab pid3, gen(pid_)
rename pid_1 democrat
rename pid_2 independent
rename pid_3 republican
label var democrat "Democrat (1=yes)"
label var republican "Republican (1=yes)"
label var independent "Pure Independent (1=yes)"

foreach i of varlist full_cost full_freedom  full_income full_population full_exports mil_purpose ctry_2-ctry_21{
gen XdemocratX`i'=democrat*`i'
gen XindependentX`i'=independent*`i'
gen XrepublicanX`i'=republican*`i'
local label : variable label `i'
label var XdemocratX`i' "`label' x Democrat"
label var XindependentX`i' "`label' x Pure Independent"
label var XrepublicanX`i' "`label' x Republican"
}

reg conjoint_ full_cost full_freedom  full_income full_population full_exports mil_purpose ctry_10 ctry_2 ctry_14 ctry_17 ctry_3 ctry_5 ctry_11 ctry_7 ctry_12 ctry_21 ctry_19 ctry_18 ctry_16 ctry_15 ctry_6 ctry_20 ctry_4 ctry_8 ctry_13 ctry_9 Xdemocrat* Xindependent* democrat independent, cluster( responseid)
outreg using "A8_party_mod", se bracket tdec(3) replace label 


reg conjoint_ full_cost pctile_freedom  pctile_income pctile_population pctile_exports mil_purpose ctry_10 ctry_2 ctry_14 ctry_17 ctry_3 ctry_5 ctry_11 ctry_7 ctry_12 ctry_21 ctry_19 ctry_18 ctry_16 ctry_15 ctry_6 ctry_20 ctry_4 ctry_8 ctry_13 ctry_9 Xdemocrat* Xindependent* democrat independent, cluster( responseid)
margins, dydx(full_cost pctile_freedom  pctile_income pctile_population pctile_exports mil_purpose ctry_10	ctry_17	ctry_2	ctry_11	ctry_5	ctry_14	ctry_12	ctry_3	ctry_7	ctry_15	ctry_21	ctry_16	ctry_18	ctry_19	ctry_4	ctry_20	ctry_6	ctry_13	ctry_9	ctry_8) post
eststo republicans

reg conjoint_ full_cost pctile_freedom  pctile_income pctile_population pctile_exports mil_purpose ctry_10 ctry_2 ctry_14 ctry_17 ctry_3 ctry_5 ctry_11 ctry_7 ctry_12 ctry_21 ctry_19 ctry_18 ctry_16 ctry_15 ctry_6 ctry_20 ctry_4 ctry_8 ctry_13 ctry_9 Xdemocrat* Xrepublican* democrat republican, cluster( responseid)
margins, dydx(full_cost pctile_freedom  pctile_income pctile_population pctile_exports mil_purpose ctry_10	ctry_17	ctry_2	ctry_11	ctry_5	ctry_14	ctry_12	ctry_3	ctry_7	ctry_15	ctry_21	ctry_16	ctry_18	ctry_19	ctry_4	ctry_20	ctry_6	ctry_13	ctry_9	ctry_8) post
eststo independents

reg conjoint_ full_cost pctile_freedom  pctile_income pctile_population pctile_exports mil_purpose ctry_10 ctry_2 ctry_14 ctry_17 ctry_3 ctry_5 ctry_11 ctry_7 ctry_12 ctry_21 ctry_19 ctry_18 ctry_16 ctry_15 ctry_6 ctry_20 ctry_4 ctry_8 ctry_13 ctry_9 Xrepublican* Xindependent* republican independent, cluster( responseid)
margins, dydx(full_cost pctile_freedom  pctile_income pctile_population pctile_exports mil_purpose ctry_10	ctry_17	ctry_2	ctry_11	ctry_5	ctry_14	ctry_12	ctry_3	ctry_7	ctry_15	ctry_21	ctry_16	ctry_18	ctry_19	ctry_4	ctry_20	ctry_6	ctry_13	ctry_9	ctry_8) post
eststo democrats

coefplot (republicans, msymbol(O) connect(none) mcolor(gs6)  ciopts(lcolor(gs6) lwidth(thin) msize(vtiny)) label(Republicans))  (democrats, msymbol(sh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Democrats)), keep(full_cost pctile_freedom  pctile_income pctile_population pctile_exports mil_purpose ) xline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(label(2 "Republican") label (4 "Democrats")  region(lcolor(white) color(none)) cols(3) colgap(10) keygap(1) size(small))  title("Panel A: Core Treatment Effects", size(medsmall))  coeflabels(,wrap(20))
graph save Graph "fX_party_a.gph", replace

coefplot (republicans, msymbol(O) connect(none) mcolor(gs6)  ciopts(lcolor(gs6) lwidth(thin) msize(vtiny)) label(Republicans))  (democrats, msymbol(sh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Democrats)), keep(ctry_2 ctry_5  ctry_10  ctry_11  ctry_12  ctry_14  ctry_17) xline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(label(2 "Republican") label (4 "Democrats") region(lcolor(white) color(none)) cols(3) colgap(10) keygap(1) size(small))  title("Panel B: Greater Middle East", size(medsmall))  coeflabels(,wrap(20))
graph save Graph "fX_party_b.gph", replace

coefplot (republicans, msymbol(O) connect(none) mcolor(gs6)  ciopts(lcolor(gs6) lwidth(thin) msize(vtiny)) label(Republicans))  (democrats, msymbol(sh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Democrats)), keep(ctry_4 ctry_6 ctry_7  ctry_13  ctry_15  ctry_16  ctry_18  ctry_19  ctry_20) xline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(label(2 "Republican") label(4 "Democrats")  region(lcolor(white) color(none)) cols(3) colgap(10) keygap(1) size(small))  title("Panel C: Africa", size(medsmall))  coeflabels(,wrap(20))
graph save Graph "fX_party_c.gph", replace

coefplot (republicans, msymbol(O) connect(none) mcolor(gs6)  ciopts(lcolor(gs6) lwidth(thin) msize(vtiny)) label(Republicans))  (democrats, msymbol(sh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Democrats)), keep(ctry_3 ctry_8  ctry_9  ctry_21) xline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(label(2 "Republican") label (4 "Democrats")  region(lcolor(white) color(none)) cols(3) colgap(10) keygap(1) size(small))  title("Panel D: Other Countries", size(medsmall))  coeflabels(,wrap(20))
graph save Graph "fX_party_d.gph", replace

grc1leg fX_party_a.gph fX_party_b.gph fX_party_c.gph fX_party_d.gph,  b1title("Estimated Effect on Probability of Selecting Proposal", size(small)) cols(2) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) position(6) ring(5) note(NOTE: Reference category for country name estimates = Country not named, size(small))
graph export "F5_pid_moderation.eps", as(eps)  replace


**** PROPOSAL CHAR FX x NAME
reg conjoint_ c.full_cost##ctry_1 mil_purpose##ctry_1, cluster( responseid)
//slightly less sensitive to cost when country name provided


///Locally weight polynomial regressions
foreach i of varlist full_*{
local label : variable label `i'
twoway (lpolyci conjoint_ `i' if ctry_1==1, lcolor(black) ciplot(rline) blcolor(gs8) blwidth(thin)), graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none)) xlabel(none) title("`label'") xtitle("") ytitle("Probability of Selecting Proposal", height(5)) ylabel(.4(.1).6) legend(off)
graph save Graph "lpoly_`i'.gph", replace
}
graph combine lpoly_full_cost.gph lpoly_full_freedom.gph lpoly_full_income.gph lpoly_full_population.gph lpoly_full_exports.gph,  b1title("Value of Experimental Treatment (lowest to highest)", size(medium)) l1title("Probability of Selecting Proposal", size(medium))  cols(2) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  
graph export "A4_lpoly.eps", as(eps) replace

